<?php
/**
 * 
 */
namespace Copilot\Client;

/**
 * An asset is a container for a downloadable file. 
 * This can be a image, a document or some other kind of file.
 * 
 * @author M. Fischboeck
 * @since 15.28
 *
 */
class Asset {
	
	/**
	 * @internal
	 * @var unknown
	 */
	private $_asset;
	
	/**
	 * @internal
	 * @var unknown
	 */
	private $_tags = array();
	
	/**
	 * Constructor for internal usage only
	 * @internal
	 * @param object $asset The asset as retrieved from the API
	 */
	public function __construct($asset) {
		$this->_asset = $asset;
		foreach ($asset->tags as $tag) {
			array_push($this->_tags, $tag->tagName);
		}
	}
	
	/**
	 * Returns the id of the underlaying asset
	 * @return string The id of the asset
	 */
	public function getId() {
		return $this->_asset->id;
	}
	
	/**
	 * Returns the filename of the asset
	 * @return string The assets filename.
	 */
	public function getFilename() {
		return $this->_asset->filename;
	}
	
	/**
	 * Returns the mimetype as per RFC2046 of this asset
	 * @return string The assets mimetype
	 */
	public function getMimeType() {
		return $this->_asset->mimeType;
	}
	
	/**
	 * Returns a string of tags, this asset contains
	 * @return array Array of strings with tagnames the asset contains
	 */
	public function getTags() {
		return $this->_tags;
	}
	
	/**
	 * Returns whether or not the asset has the given tag
	 * @param string $tag The name of the tag
	 * @return boolean True if the asset has this tag, false otherwise
	 */
	public function containsTag($tag) {
		foreach ($this->_tags as $t)
			if ($t == $tag) return true;
		return false;
	}
	
	/**
	 * Returns the size in bytes of the file
	 * @return integer The size of the file in bytes
	 */
	public function getSize() {
		return $this->_asset->size;
	}
	
	/**
	 * Returns the assets descriptional text
	 * @return string The assets description
	 */
	public function getDescription() {
		return $this->_asset->description;
	}
	
	/**
	 * Returns the download URL from where the asset could been retrieved.
	 * @param integer $width If the asset is of mimetype image/* the link will point to an image in that size
	 * @return string The URL to the given file
	 */
	public function getDownloadUrl($width = NULL) {
		if (strpos($this->_asset->mimeType, "image/") == 0) {
			return $this->_asset->downloadUrl . "?width=" . $width;
		} else
			return $this->_asset->downloadUrl;
	}
	
	/**
	 * If the asset has a mimetype of image/* returns the original images width
	 * @return integer The images original width or NULL if the asset is not an image
	 */
	public function getOriginalWidth() {
		if (strpos($this->_asset->mimeType, "image/") == 0) {
			return $this->_asset->width;
		} 
		return NULL;
	}
	
	/**
	 * If the asset has a mimetype of image/* returns the original images height
	 * @return integer The images original height or NULL if the asset is not an image
	 */
	public function getOriginalHeight() {
		if (strpos($this->_asset->mimeType, "image/") == 0) {
			return $this->_asset->height;
		} 
		return NULL;
	}
}
?>