<?php
/**
 * 
 */
namespace Copilot\Client;
require_once('class.Location.php');

/**
 * An event contains information about the real world event (either concert or event).
 * 
 * @author M. Fischboeck
 * @since 15.28
 *
 */
class Event {

	/**
	 * @var object Internal data
	 * @internal
	 */
	private $_data;
	
	/**
	 * The location of the event for internal usage
	 * @var Location The events location
	 * @internal
	 */
	private $location;
	
	/**
	 * The events main act
	 * @var Artist The artist of the event
	 * @internal private
	 */
	private $mainact;
	
	/**
	 * The support acts of the event
	 * @var Array
	 * @internal private
	 */
	private $supportActs = array();
	
	
	/**
	 * Internal constructor. Do not use!
	 * @internal
	 * @param object $json The object from the API
	 */
	public function __construct($json) {
		$this->_data = $json;
		
		// initialize the location
		if ($this->_data->location != NULL) {
			$this->location = new Location($this->_data->location);
		} else 
			$this->location = NULL;
		
		// initialize the mainact
		$this->mainAct = NULL;
		foreach ($this->_data->cast as $c) {
			if ($c->mainAct == true) {
				$this->mainact = new Artist($c->artist);
			}
		}
		
		// initialize support acts
		foreach ($this->_data->cast as $c) {
			if ($c->mainAct != true) {
				array_push($this->supportActs, new Artist($c->artist));
			}
		}
	}
	
	/**
	 * Returns the id of the event
	 * @return string The events id
	 */
	public function getId() {
		return $this->_data->id;
	}
	
	/**
	 * Returns the descriptional text of the event
	 * @return string The events description
	 */
	public function getDescription() {
		return $this->_data->description;
	}
	
	/**
	 * Returns the date of the event in the desired date format.
	 * Note that this is really just a date and does not include time information
	 * @param string $format The format of the date.
	 * @return string The date in the given format, or in the original 
	 * format if the date could not be parsed or an empty string if no date is available
	 */
	public function getDateOfEvent($format = "d.m.Y") {
		if (isset($this->_data->dateOfEvent)) {
			$d = date_create_from_format("Y-m-d", $this->_data->dateOfEvent);
			if ($d != FALSE)
				return date_format($d, $format);
			else return $this->data->dateOfEvent;
		}
		return "";
	}
	
	/**
	 * Returns the entrance time for the event (does not contain date information)
	 * @param string $format The format in which to display the entrance time
	 * @return string The entrance time in the given format or in the original format if the time could not be parsed
	 * or an empty string if the time is not available
	 */
	public function getEntranceTime($format = "H:i") {
		if (isset($this->_data->entrance)) {
			$d = date_create_from_format("H:i:s.000", $this->_data->entrance);
			if ($d != FALSE)
				return date_format($d, $format);
			else return $this->_data->entrance;
		} else return "";
	}
	
	/**
	 * Returns the start time of the event (does not contain date information)
	 * @param string $format The format in which to display the start time
	 * @return string The start time in the given format or in the original format if the time could not be parsed
	 * or an empty string if the time is not available
	 */
	public function getStartTime($format = "H:i") {
		if (isset($this->_data->start)) {
			$d = date_create_from_format("H:i:s.000", $this->_data->start);
			if ($d != FALSE)
				return date_format($d, $format);
			else return $this->_data->start;
		} else return "";
	}
	
	/**
	 * Returns an URL pointing to a resource from where to buy tickets for the event
	 * @return string|NULL The URL to the webpage or NULL if the information is not available
	 */
	public function getTicketUrl() {
		if (isset($this->_data->ticketURL))
			return $this->_data->ticketURL;
		else return NULL;
	}
	
	/**
	 * Returns a string containing a phone number from where to buy tickets for the event
	 * @return string|NULL The phone number or NULL if the information is not available
	 */
	public function getTicketPhone() {
		if (isset($this->_data->ticketPhone)) 
			return $this->_data->ticketPhone;
		else return NULL;
	}
	
	/**
	 * Returns whether or not the event is sold out (no more tickets available execpt for box office)
	 * @return 	boolean|NULL 	True when the event is sold out, false if not. Might return NULL if the information
	 * is not available
	 */
	public function isSoldOut() {
		if (isset($this->_data->soldOut))
			return $this->_data->soldOut;
		else return NULL;
	}
	
	/**
	 * Returns the name of the tour the event belongs to
	 * @return string The tour name or NULL if the event does not have a tour.
	 */
	public function getTourName() {
		if ($this->_data->tour != NULL) {
			return $this->_data->tour->title;
		}
		else return NULL;
	}
	
	/**
	 * Returns the descriptional information of the tour the event belongs to
	 * @return string The description of the tour or NULL if the event does not have a tour.
	 */
	public function getTourDescription() {
		if ($this->_data->tour != NULL) {
			return $this->_data->tour->description;
		}
		return NULL;
	}
	
	/**
	 * Returns the location the event will take place at
	 * @return Location The location of the event or NULL if that information is not available
	 */
	public function getLocation() {
		return $this->location;
	}
	
	/**
	 * Returns the main act of the event.
	 * @return Artist|NULL The mainact of the event or NULL if the information is not available
	 */
	public function getMainAct() {
		return $this->mainact;
	}
	
	
	/**
	 * Returns an URL to a suitable image for the event.
	 * The image returned depends on the available data. The image will be resolved in the following
	 * order 1) The artists main image or 2) the artists band logo or 3) the artists press image
	 * @param int 		$width 	The width of the image to be returned
	 * @return string 	The images URL or NULL if no image can be found
	 */
	public function getEventImageLink($width) {
		$retval = $this->mainact->getMainImageLinks($width);
		if (count($retval) != 0)
			return $retval[0];

		$retval = $this->mainact->getBandLogoLinks($width);
		if (count($retval) != 0)
			return $retval[0];
		
		$retval = $this->mainact->getPressImageLinks($width);
		if (count($retval) != 0)
			return $retval[0];
		return NULL;
	}
	
	/**
	 * Returns all support acts in the given event
	 * @return Artist[] An array of Artist's that appear as support acts
	 */
	public function getSupportActs() {
		return $this->supportActs;
	}
}
?>