<?php 
/**
 * 
 */
namespace Copilot\Client;
/**
 * This class represents a news item from the co*pilot news feed.
 * @author M. Fischboeck
 *
 */
class News {
	
	/**
	 * @internal
	 * @var unknown
	 */
	private $_data;
	/**
	 * @internal
	 * @var unknown
	 */
	private $mainImage;
	
	/**
	 * @internal
	 * @var unknown
	 */
	private $assets;
	
	/**
	 * @internal
	 * @param unknown $data
	 */
	public function __construct($data) {
		$this->_data = $data;
		$this->mainImage = new Asset($this->_data->image);
		$this->assets = new AssetCollection($this->_data->assets);
	}
	
	/**
	 * Returns the id of the news entry
	 * @return string The id of the news entry
	 */
	public function getId() {
		return $this->_data->id;
	}
	
	/**
	 * Returns the headline of the news entry
	 * @return string The headline
	 */
	public function getHeadline() {
		return $this->_data->headline;
	}
	
	/**
	 * Returns an unformatted teaser text
	 */
	public function getTeaser() {
		return $this->_data->teaser;
	}
	
	/**
	 * Returns the news text in HTML format
	 */
	public function getText() {
		return $this->_data->text;
	}
	
	/**
	 * Returns the date the news has been published
	 * @param string $format The format for the date (default is d.m.Y H:i)
	 * @return string The formatted date string or an empty string if the date could not be parsed
	 */
	public function getDatePublished($format = "d.m.Y H:i") {
		$d = date_create_from_format(\DateTime::ISO8601, $this->_data->publishDate);
		if ($d == FALSE)
			$d = date_create_from_format("Y-m-d\TH:i\Z", $this->_data->publishDate);
		if ($d == FALSE)
			return "";
		return date_format($d, $format);
	}
	
	/**
	 * Returns a link to the main image of the news entry for the given image width
	 * @param unknown $width The width in pixels
	 * @return string The link form where to fetch the image. Might be empty when no image is available
	 */
	public function getMainImageLink($width) {
		if (isset($this->mainImage)) 
			return $this->mainImage->getDownloadUrl($width);
		return "";
	}
	
	/**
	 * Returns the asset that corresponds to the main image
	 * @return Asset The asset or null if no image is set.
	 */
	public function getMainImage() {
		return $this->mainImage;
	}
	
	/**
	 * Returns whether or not the news is referencing some artist
	 * @returns boolean True if the news references an artist, false otherwise
	 */
	public function hasArtistReferences() {
		if (!isset($this->_data->references))
			return false;
		foreach ($this->_data->references as $ref) {
			if ($ref->type == "ARTIST")
				return true;
		}
		return false;
	}
	
	/**
	 * Returns the references the news are pointing to.
	 * This is usually returning [{ type : ARTIST, id : xyz }]
	 * This means that the news is related to the artist with the id xyz.
	 * Could be useful for linking to an artists detail page.
	 * @returns array: The reference type or NULL if no reference is set
	 */
	public function getReferences() {
		if (isset($this->_data->references)) { 
			return $this->_data->references;
		} else return NULL;
	}
}
?>