<?php
namespace Copilot\Client;

/**
 * A page object to define page sizes and the like.
 * 
 * For all API calls that return multiple elements co*pilot returns a page. 
 * A page contains 0 to n elements and some information about the page that
 * can be used for pagination. 
 * Whenever a call is made with a page object, the page object will be
 * populated with the information for that call. 
 * 
 * Example:
 * $page = new Page(30, 1);
 * $client->getAgencyArtists($page);
 * 
 * The page will now contain the information about how much artists are available
 * at all ($totalElements), how the elements are sorted ($sort) and how many
 * pages can be retrieved with that page size.
 * To load the next page you would simply call:
 * 
 * $client->getAgenyArtists(new Page(30, 2)); 
 * 
 * which in turn will return the next 30 artists from page 2.
 * 
 * @author M. Fischboeck
 *
 */
class Page {
	
	/**
	 * The maximum amount of elements on that page
	 * @var int The pages maximum size
	 */
	public $size;
	
	/**
	 * The page number you want to access
	 * @var int The page number
	 */
	public $number;
	
	/**
	 * The property after which the elements are sorted
	 * @var string The property to sort after
	 */
	public $sort;
	
	/**
	 * The direction you want to sort
	 * @var string Either asc or desc
	 */
	public $direction;
	
	/**
	 * The number of total elements for the current API call
	 * @var int The maximum number of elements to be returned for the API call
	 */
	public $totalElements;
	
	/**
	 * The amount of pages for the current page size
	 * @var int The maximum amount of pages
	 */
	public $totalPages;
	
	/**
	 * States if this is the last page
	 * @var boolean True, if this is the last page
	 */
	public $last = false;
	
	/**
	 * States if this is the first page
	 * @var boolean True, if this is the first page
	 */
	public $first = true;

	/**
	 * Constructs a new page object with the given size and page number
	 * @param int $size The size of the page
	 * @param int $number The page number
	 */
	public function __construct($size, $number) {
		$this->size = $size;
		$this->number = $number;
	}
}